@@ -260,7 +260,7 @@ nhanesTables <- function(data_group, year, nchar=100, details = FALSE, namesonly
 #' Each data table contains multiple, sometimes more than 100, fields. It is helpful to list the field
 #' descriptions to ascertain quickly if a data table is of interest.
 #' @examples
-#' nhanesTableVars('LAB', 'CBC_E')
+#' \donttest{nhanesTableVars('LAB', 'CBC_E')}
 #' \donttest{nhanesTableVars('EXAM', 'OHX_E', details=TRUE, nchar=50)}
 #' \donttest{nhanesTableVars('DEMO', 'DEMO_F', namesonly = TRUE)}
 #' @export
@@ -312,8 +312,8 @@ nhanesTableVars <- function(data_group, nh_table, details = FALSE, nchar=100, na
 #' are stored in SAS '.XPT' format. Function nhanes cannot be used to import limited 
 #' access data.
 #' @examples 
-#' nhanes('BPX_E')
-#' nhanes('FOLATE_F')
+#' \donttest{nhanes('BPX_E')}
+#' \donttest{nhanes('FOLATE_F')}
 #' @export
 #' 
 nhanes <- function(nh_table) {
@@ -620,7 +620,7 @@ nhanesSearch <- function(search_terms=NULL, exclude_terms=NULL, data_group=NULL,
 #' that match a given name pattern. Only a single pattern may be entered.
 #' @examples
 #' \donttest{nhanesSearchTableNames('BMX')}
-#' nhanesSearchTableNames('HPVS', includerdc=TRUE, details=TRUE)
+#' \donttest{nhanesSearchTableNames('HPVS', includerdc=TRUE, details=TRUE)}
 #' @export
 #' 
 nhanesSearchTableNames <- function(pattern=NULL, ystart=NULL, ystop=NULL, includerdc=FALSE, nchar=100, details=FALSE) {
@@ -868,7 +868,7 @@ nhanesTranslate <- function(nh_table, colnames=NULL, data = NULL, nchar = 32,
   }
   
   if(dxa) {
-    code_translation_url <- "https://wwwn.cdc.gov/Nchs/Nhanes/2005-2006/DXX_D.htm"
+    code_translation_url <- "https://wwwn.cdc.gov/nchs/data/nhanes/dxa/dxx_d.htm"
   } else {
     nh_year <- .get_year_from_nh_table(nh_table)
     if(is.null(nh_year)) {
